==> 0.0.2.zip: swe1-mtcg/src/test/java/TradingDealTest.java <==
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

import java.util.ArrayList;

import static org.junit.Assert.assertTrue;

public class TradingDealTest {

    private TradingDeal tradingDeal;
    private Cards newCards, cards, nochNewCards;
    private Card newCard, card;
    private ArrayList<Card> cardsArrayList, cardsArrayList2, cardsArrayList3;
    private Stack stack;
    private User user, userNew;

    @BeforeEach
    void setUp() {
        //Stack
        card = new Card("Name", 10, ElementTyp.WATER, CardType.MONSTER);
        newCard = new Card("NameNew", 10, ElementTyp.WATER, CardType.SPELL);
        cardsArrayList = new ArrayList<Card>();
        cardsArrayList2 = new ArrayList<Card>();
        cardsArrayList3 = new ArrayList<Card>();
        cardsArrayList.add(card);
        cardsArrayList2.add(newCard);
        cards = new Cards(cardsArrayList);
        newCards = new Cards(cardsArrayList2);
        nochNewCards = new Cards(cardsArrayList3);
        stack = new Stack(cards, nochNewCards);

        //Coins
        Coins coins = new Coins(10);
        //User
        Credentials credentials = new Credentials();
        user = new User(credentials, "name", "nachname", "email", stack, coins);
        userNew = new User(credentials, "nameNew", "nachnameNew", "emailNew", stack, coins);

        //Trading Deal
        Card cardToTrade = card;
        ElementTyp requiredElementType = ElementTyp.FIRE;
        double requiredMinDamage = 100;
        CardType requiredCardType = CardType.MONSTER;
        tradingDeal = new TradingDeal(user, cardToTrade, requiredElementType, requiredMinDamage, requiredCardType);
    }

    @Test
    void test_getTradingUser() {
        User result = tradingDeal.getTradingUser();
        assertTrue(result==user);
    }
    @Test
    void test_getCardToTrade() {
        Card result = tradingDeal.getCardToTrade();
        assertTrue(result==card);
    }
    @Test
    void test_getRequiredElementType() {
        ElementTyp result = tradingDeal.getRequiredElementType();
        assertTrue(result==ElementTyp.FIRE);
    }
    @Test
    void test_getRequiredMinDamage() {
        int result = tradingDeal.getRequiredMinDamage();
        assertTrue(result==100);
    }
    @Test
    void test_getRequiredCardType() {
        CardType result = tradingDeal.getRequiredCardType();
        assertTrue(result==CardType.MONSTER);
    }

    @Test
    void test_setTradingUser() {
        tradingDeal.setTradingUser(userNew);
        User result = tradingDeal.getTradingUser();
        assertTrue(result==userNew);
    }
    @Test
    void test_setCardToTrade() {
        tradingDeal.setCardToTrade(newCard);
        Card result = tradingDeal.getCardToTrade();
        assertTrue(result==newCard);
    }
    @Test
    void test_setRequiredElementType() {
        tradingDeal.setRequiredElementType(ElementTyp.WATER);
        ElementTyp result = tradingDeal.getRequiredElementType();
        assertTrue(result==ElementTyp.WATER);
    }
    @Test
    void test_setRequiredMinDamage() {
        tradingDeal.setRequiredMinDamage(10);
        int result = tradingDeal.getRequiredMinDamage();
        assertTrue(result==10);
    }
    @Test
    void test_setRequiredCardType() {
        tradingDeal.setRequiredCardType(CardType.SPELL);
        CardType result = tradingDeal.getRequiredCardType();
        assertTrue(result==CardType.SPELL);
    }
}

==> 0.1.1.zip: swe1-mtcg/src/test/java/TradingDealTest.java <==
import at.reisinger.*;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

import java.util.ArrayList;

import static org.junit.jupiter.api.Assertions.assertTrue;


public class TradingDealTest {

    private TradingDeal tradingDeal;
    private Cards newCards, cards, nochNewCards;
    private Card newCard, card;
    private ArrayList<Card> cardsArrayList, cardsArrayList2, cardsArrayList3;
    private Stack stack;
    private User user, userNew;

    @BeforeEach
    void setUp() {
        //at.reisinger.Stack
        card = new Card("Name", 10, ElementTyp.WATER, CardType.MONSTER);
        newCard = new Card("NameNew", 10, ElementTyp.WATER, CardType.SPELL);
        cardsArrayList = new ArrayList<Card>();
        cardsArrayList2 = new ArrayList<Card>();
        cardsArrayList3 = new ArrayList<Card>();
        cardsArrayList.add(card);
        cardsArrayList2.add(newCard);
        cards = new Cards(cardsArrayList);
        newCards = new Cards(cardsArrayList2);
        nochNewCards = new Cards(cardsArrayList3);
        stack = new Stack(cards, nochNewCards);

        //at.reisinger.Coins
        Coins coins = new Coins(10);
        //at.reisinger.User
        Credentials credentials = new Credentials("username", "passwort");
        Credentials newCredentials = new Credentials("usernamenew", "passwortnew");
        user = new User(credentials, "name", "nachname", "email", coins);
        userNew = new User(newCredentials, "nameNew", "nachnameNew", "emailNew", coins);

        //Trading Deal
        Card cardToTrade = card;
        ElementTyp requiredElementType = ElementTyp.FIRE;
        double requiredMinDamage = 100;
        CardType requiredCardType = CardType.MONSTER;
        tradingDeal = new TradingDeal(user, cardToTrade, requiredElementType, requiredMinDamage, requiredCardType);
    }

    /*
    @Test
    void test_getTradingUser() {
        User result = tradingDeal.getTradingUser();
        assertTrue(result.equals(user));
    }
    */

    @Test
    void test_getCardToTrade() {
        Card result = tradingDeal.getCardToTrade();
        assertTrue(result.equals(card));
    }
    @Test
    void test_getRequiredElementType() {
        ElementTyp result = tradingDeal.getRequiredElementType();
        assertTrue(result==ElementTyp.FIRE);
    }
    @Test
    void test_getRequiredMinDamage() {
        double result = tradingDeal.getRequiredMinDamage();
        assertTrue(result==100);
    }
    @Test
    void test_getRequiredCardType() {
        CardType result = tradingDeal.getRequiredCardType();
        assertTrue(result==CardType.MONSTER);
    }

    /*
    @Test
    void test_setTradingUser() {
        tradingDeal.setTradingUser(userNew);
        User result = tradingDeal.getTradingUser();
        assertTrue(result.equals(userNew));
    }
    */

    @Test
    void test_setCardToTrade() {
        tradingDeal.setCardToTrade(newCard);
        Card result = tradingDeal.getCardToTrade();
        assertTrue(result==newCard);
    }
    @Test
    void test_setRequiredElementType() {
        tradingDeal.setRequiredElementType(ElementTyp.WATER);
        ElementTyp result = tradingDeal.getRequiredElementType();
        assertTrue(result==ElementTyp.WATER);
    }
    @Test
    void test_setRequiredMinDamage() {
        tradingDeal.setRequiredMinDamage(10);
        double result = tradingDeal.getRequiredMinDamage();
        assertTrue(result==10);
    }
    @Test
    void test_setRequiredCardType() {
        tradingDeal.setRequiredCardType(CardType.SPELL);
        CardType result = tradingDeal.getRequiredCardType();
        assertTrue(result==CardType.SPELL);
    }
}
